pub struct PingHandler { /* private fields */ }Expand description
Protocol handler that handles pinging the remote at a regular period and answering ping queries.
If the remote doesn’t respond, produces an error that closes the connection.
Implementations
Sourceimpl PingHandler
impl PingHandler
Sourcepub fn new(config: PingConfig) -> Self
pub fn new(config: PingConfig) -> Self
Builds a new PingHandler with the given configuration.