pub struct Event {
pub peer: PeerId,
pub result: Result,
}
Event generated by the Ping network behaviour.
The peer ID of the remote.
The result of an inbound or outbound ping.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.