Structs
- Ping
Config - The configuration for outbound pings.
- Ping
Handler - Protocol handler that handles pinging the remote at a regular period and answering ping queries.
Enums
- Ping
Failure - An outbound ping failure.
- Ping
Success - The successful result of processing an inbound or outbound ping.
Type Aliases
- Ping
Result - The result of an inbound or outbound ping.